CShake

Struct CShake 

pub struct CShake<const RATE: usize> { /* private fields */ }
cSHAKE hasher generic over rate.

Rate MUST be either 168 or 136 for cSHAKE128 and cSHAKE256 respectively.

Implementations

Source

impl<const RATE: usize> CShake<RATE>

pub fn new_with_function_name( function_name: &[u8], customization: &[u8], ) -> Self

Creates a new cSHAKE instance with the given function name and customization.

Note that the function name is intended for use by NIST and should only be set to values defined by NIST. You probably don’t need to use this function.